@@ -1,5 +1,5 @@
 package System::Command;
-$System::Command::VERSION = '1.111';
+$System::Command::VERSION = '1.112';
 use warnings;
 use strict;
 use 5.006;
@@ -268,7 +268,7 @@ sub new {
 
     # create the subprocess reaper and link the handles and command to it
     ${*$in} = ${*$out} = ${*$err} = $self->{reaper}    # typeglobs FTW
-        = System::Command::Reaper->new($self);
+      = System::Command::Reaper->new( $self, { trace => $trace, th => $th } );
 
     return $self;
 }
@@ -284,8 +284,6 @@ sub close         { $_[0]{reaper}->close() }
 
 1;
 
-
-
 =pod
 
 =head1 NAME
@@ -294,7 +292,7 @@ System::Command - Object for running system commands
 
 =head1 VERSION
 
-version 1.111
+version 1.112
 
 =head1 SYNOPSIS
 
@@ -629,7 +627,6 @@ See L<http://dev.perl.org/licenses/> for more information.
 
 =cut
 
-
 __END__
 
 # ABSTRACT: Object for running system commands
